@@ -16,11 +16,17 @@ using System;
 using System.Collections;
 using System.IO;
 using System.Text;
+using System.Runtime.InteropServices;
 
 namespace Imendio.Blam {
 
     public class Application : Program {
-        public static Application TheApp;
+
+	[DllImport("libc")]
+	private static extern int prctl(int option, byte [] arg2, ulong arg3, 
+    	ulong arg4, ulong arg5);
+        
+	public static Application TheApp;
 
         [Widget] Gtk.Window         mainWindow = null;
         [Widget] Gtk.ScrolledWindow channelListSw = null;
@@ -715,8 +721,18 @@ namespace Imendio.Blam {
             //mCollection.RefreshAll ();
         }
 
+	public static void SetProcessName(string name)
+	{
+	    if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name + "\0"), 
+        	0, 0, 0) != 0) {
+        	throw new ApplicationException("Error setting process name: " + 
+        	    Mono.Unix.Native.Stdlib.GetLastError());
+	    }
+	}
+
         public static void Main(string[] args)
         {
+            SetProcessName("blam");
             TheApp = new Application (args);
             TheApp.Run ();
             // new Application(args).Run();
