@@ -147,15 +147,16 @@ namespace Imendio.Blam {
 
 	public void Add (Channel channel)
 	{
-	    // Not the most efficiant way of doing things :)
+	    // Not the most efficient way of doing things :)
 	    foreach (Channel ch in mChannels) {
 		if (channel.Url == ch.Url) {
 		    return;
 		}
 	    }
 
-	    mChannels.Add (channel);
-	    Refresh (channel);
+        channel.Name = channel.Url;
+        mChannels.Add (channel);
+        Refresh (channel);
 
 	    if (ChannelAdded != null) {
 		ChannelAdded (channel);
