@@ -13,11 +13,14 @@ using System.Text;
 
 namespace Imendio.Blam {
     public class ChannelDialog {
-	[Widget] Gtk.Dialog channelDialog = null;
-	[Widget] Gtk.Entry  nameEntry     = null;
-	[Widget] Gtk.Entry  urlEntry      = null;
-	[Widget] Gtk.Button okButton      = null;
-	[Widget] Gtk.Image  dialogImage   = null;
+    [Widget] Gtk.Dialog channelDialog = null;
+    [Widget] Gtk.Entry  nameEntry     = null;
+    [Widget] Gtk.Entry  urlEntry      = null;
+    [Widget] Gtk.Entry  usernameEntry = null;
+    [Widget] Gtk.Entry  passwordEntry = null;
+    [Widget] Gtk.Entry  keywordEntry  = null;
+    [Widget] Gtk.Button okButton      = null;
+    [Widget] Gtk.Image  dialogImage   = null;
 
 	private Channel     mChannel;
 	
@@ -62,7 +65,10 @@ namespace Imendio.Blam {
 	    
 	    nameEntry.Text = channel.Name;
 	    urlEntry.Text = channel.Url;
-	    
+	    keywordEntry.Text = channel.Keywords;
+	    usernameEntry.Text = channel.http_username;
+	    passwordEntry.Text = channel.http_password;
+
 	    channelDialog.ShowAll ();
 	}
 	
@@ -80,6 +86,9 @@ namespace Imendio.Blam {
 	        mChannel.Type = "";
 	    }
 	    mChannel.Url = urlEntry.Text;
+	    mChannel.Keywords = keywordEntry.Text;
+	    mChannel.http_username = usernameEntry.Text;
+	    mChannel.http_password = passwordEntry.Text;
 
 	    mApp.CCollection.Update (mChannel);
 
