@@ -60,10 +60,12 @@ namespace Imendio.Blam {
     }
     
     class AddChannelDialog {
-	[Widget] Gtk.Dialog addChannelDialog = null;
-	[Widget] Gtk.Entry  urlEntry         = null;
-	[Widget] Gtk.Image  dialogImage      = null;
-	[Widget] Gtk.Button okButton         = null;
+    [Widget] Gtk.Dialog addChannelDialog = null;
+    [Widget] Gtk.Entry  urlEntry         = null;
+    [Widget] Gtk.Entry	usernameEntry	 = null;
+    [Widget] Gtk.Entry	passwordEntry	 = null;
+    [Widget] Gtk.Image  dialogImage      = null;
+    [Widget] Gtk.Button okButton         = null;
 	
 	private Application mApp;
 	
@@ -84,17 +86,22 @@ namespace Imendio.Blam {
 
 	public void Show ()
 	{
-	    urlEntry.Text = "";
+	    urlEntry.Text = ""; //otherwise it will keep adding it on to the end
+	    urlEntry.PasteClipboard();
+	    usernameEntry.Text = "";
+	    passwordEntry.Text = "";
 	 
 	    addChannelDialog.ShowAll ();
 	}
 
-	public void Show (string url)
-	{
-	    urlEntry.Text = url;
-
-	    addChannelDialog.ShowAll ();
-	}
+    public void Show (string url)
+    {
+        urlEntry.Text = url;
+        usernameEntry.Text = "";
+        passwordEntry.Text = "";
+	    
+        addChannelDialog.ShowAll ();
+    }
 
 	public void CancelButtonClicked (object obj, EventArgs args)
 	{
@@ -106,6 +113,8 @@ namespace Imendio.Blam {
 	    Channel channel = new Channel ();
 		
 	    channel.Url = urlEntry.Text;
+	    channel.http_username = usernameEntry.Text;
+	    channel.http_password = passwordEntry.Text;
 
 	    mApp.CCollection.Add (channel);
 
