@@ -48,8 +48,8 @@ namespace Imendio.Blam {
             this.mMoz = new WebControl ();
 	   
             Conf.AddNotify (Preference.FONT_PATH,
-                            new NotifyEventHandler (FontNotifyHandler));
-	    SetFonts ();
+                                        new NotifyEventHandler (FontNotifyHandler));
+            SetFonts ();
 
             ProxyUpdatedCb ();
             Proxy.Updated += ProxyUpdatedCb;
@@ -59,9 +59,23 @@ namespace Imendio.Blam {
             mMoz.NetStart += new EventHandler (NetStartCb);
             mMoz.NetStop += new EventHandler (NetStopCb);
             mMoz.LinkMsg += new EventHandler (LinkMsgCb);
+            mMoz.NewWindow += new NewWindowHandler(WindowCb);
             
-	    mMoz.Show ();
-	    PageLoaded = false;
+            mMoz.Show ();
+            PageLoaded = false;
+        }
+        
+        private void WindowCb(object obj, NewWindowArgs args)
+        {
+            WebControl wb = obj as WebControl;
+            try {
+                Gnome.Url.Show(wb.LinkMessage);
+            }
+    	    catch (Exception e) {
+                Console.WriteLine("Couldn't show URL: " + wb.LinkMessage + e.Message);
+            }
+            
+            args.RetVal = true;
         }
         
         private void TitleChangedCb (object obj, EventArgs args)
@@ -103,17 +117,17 @@ namespace Imendio.Blam {
             mMoz.CloseStream ();
 	}
 
-	private void LinkClickedCb(object obj, OpenUriArgs args)
-	{
-	    try {
-                Gnome.Url.Show(args.AURI);
-	    }
-	    catch (Exception e) {
-                Console.WriteLine("Couldn't show URL: " + args.AURI + e.Message);
-            }
+    private void LinkClickedCb(object obj, OpenUriArgs args)
+    {
+        try {
+            Gnome.Url.Show(args.AURI);
+        }
+        catch (Exception e) {
+            Console.WriteLine("Couldn't show URL: " + args.AURI + e.Message);
+        }
 
             args.RetVal = true;
-        }
+    }
 
         private void SetFonts ()
         {
