@@ -89,7 +89,7 @@ namespace Imendio.Blam {
                     UseProxy = false;
 		    proxy = null;
 		}
-	    } catch(Exception e) {
+	    } catch(Exception) {
 		proxy = null;
 	    }
 
